# Changelog

## 2.1.0 - 2025 TBD
- Initial public release targeting integration with the
  [Planet Client for Python](https://github.com/planetlabs/planet-client-python).

## [Unreleased: 2.0.*] - YYYY-MM-DD
- All releases in the 2.0.X series are development releases, even if not
  tagged as such. This work included some shakedowns of the release pipelines.
